========
Examples
========

Here you will find some example notebooks to get more familiar with the Darts' API.
All the notebooks are also available in ``ipynb`` format
`directly on github <https://github.com/unit8co/darts/tree/master/examples>`_.


Multiple Time Series, Pre-trained Models and Covariates
=======================================================

Example notebook on training with multiple time series, pre-trained models and using covariates:

.. toctree::
   :maxdepth: 1

   examples/01-multi-time-series-and-covariates.ipynb


Data (pre) Processing
=====================

Data processing example notebook:

.. toctree::
   :maxdepth: 1

   examples/02-data-processing.ipynb


Static Covariates
=================

Static covariates example notebook:

.. toctree::
   :maxdepth: 1

   examples/15-static-covariates.ipynb


Transfer Learning Tutorial
==========================

A self-contained notebook showcasing examples of training some bigger models
on large datasets of time series, and using such models to forecast new time
series that have not been seen during training:

.. toctree::
   :maxdepth: 1

   examples/14-transfer-learning.ipynb


Hierarchical Reconciliation
===========================

A self-contained notebook showcasing how to reconcile forecasts
for hierarchical time series, using the Australian domestic tourism dataset.

.. toctree::
   :maxdepth: 1

   examples/16-hierarchical-reconciliation.ipynb


Hyperparameter Optimization
===========================

An example showcasing how to find good forecasting models
with Darts using the Optuna library for hyperparameter optimization.

.. toctree::
   :maxdepth: 1

   examples/17-hyperparameter-optimization.ipynb


Fast Fourier Transform
======================

FFT model example notebook:

.. toctree::
   :maxdepth: 1

   examples/03-FFT-examples.ipynb

Recurrent Neural Networks
=========================

RNN model example notebook:

.. toctree::
   :maxdepth: 1

   examples/04-RNN-examples.ipynb

Temporal Convolutional Networks
===============================

TCN model example notebook:

.. toctree::
   :maxdepth: 1

   examples/05-TCN-examples.ipynb

Transformer Model
=================

Transformer model example notebook:

.. toctree::
   :maxdepth: 1

   examples/06-Transformer-examples.ipynb

N-BEATS Model
=============

N-BEATS model example notebook:

.. toctree::
   :maxdepth: 1

   examples/07-NBEATS-examples.ipynb

DeepAR Model
============

DeepAR model example notebook:

.. toctree::
   :maxdepth: 1

   examples/08-DeepAR-examples.ipynb

DeepTCN Model
=============

DeepTCN model example notebook:

.. toctree::
   :maxdepth: 1

   examples/09-DeepTCN-examples.ipynb

Temporal Fusion Transformer (TFT) Model
=======================================

TFT model example notebook:

.. toctree::
   :maxdepth: 1

   examples/13-TFT-examples.ipynb

Kalman Filter Model
===================

Kalman filter model example notebook:

.. toctree::
   :maxdepth: 1

   examples/10-Kalman-filter-examples.ipynb

Gaussian Process Filter Model
=============================

Gaussian process filter model example notebook:

.. toctree::
   :maxdepth: 1

   examples/11-GP-filter-examples.ipynb

Dynamic Time Warping (DTW)
=============================

Dynamic time warping example notebook:

.. toctree::
   :maxdepth: 1

   examples/12-Dynamic-Time-Warping-example.ipynb
